"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultProjectNavigation = exports.ProjectNavigationFeatures = exports.OtherFeatures = exports.WorkflowFeatures = exports.CrmFeatures = exports.PimFeatures = exports.UserFeatures = exports.ContentFeatures = exports.CheckinFeatures = exports.ContactsNavigationNode = void 0;
const axios_api_client_1 = require("@smallstack/axios-api-client");
const typesystem_1 = require("@smallstack/typesystem");
const backoffice_icons_1 = require("./backoffice.icons");
exports.ContactsNavigationNode = {
    icon: backoffice_icons_1.BackofficeIcons.contact,
    path: typesystem_1.T_CONTACT,
    label: [
        { locale: "de_de", value: "Kontakte" },
        { locale: "en_us", value: "Contacts" }
    ],
    type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
    requiredPermission: typesystem_1.ServicePermissions.CONTACTS_READ
};
exports.CheckinFeatures = [
    {
        label: [
            { locale: "de_de", value: "Besucher" },
            { locale: "en_us", value: "Visitors" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        path: "checkin/visitors",
        icon: backoffice_icons_1.BackofficeIcons.visitors
    },
    {
        label: [
            { locale: "de_de", value: "Events" },
            { locale: "en_us", value: "Events" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        path: "checkin/events",
        icon: backoffice_icons_1.BackofficeIcons.event
    },
    {
        label: [
            { locale: "de_de", value: "Check-In Apps" },
            { locale: "en_us", value: "Check-In Apps" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        path: "checkin/apps",
        icon: backoffice_icons_1.BackofficeIcons.appsymbol
    },
    {
        label: [
            { locale: "de_de", value: "Drucker" },
            { locale: "en_us", value: "Printer" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        path: "checkin/printerconfigurations",
        icon: backoffice_icons_1.BackofficeIcons.printerconfig
    },
    {
        icon: "form",
        path: typesystem_1.F_FORM,
        label: [
            { locale: "de_de", value: "Formulare" },
            { locale: "en_us", value: "Forms" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item
    }
];
exports.ContentFeatures = [
    {
        label: [
            { locale: "de_de", value: "Kalender" },
            { locale: "en_us", value: "Calendars" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        path: "calendars",
        icon: backoffice_icons_1.BackofficeIcons.calendar
    },
    {
        label: [
            { locale: "de_de", value: "Kalender" },
            { locale: "en_us", value: "Calendars" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        path: "calendars",
        icon: backoffice_icons_1.BackofficeIcons.calendar
    },
    {
        icon: "form",
        path: typesystem_1.F_FORM,
        label: [
            { locale: "de_de", value: "Formulare" },
            { locale: "en_us", value: "Forms" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item
    },
    {
        icon: "application",
        path: typesystem_1.F_APPLICATION,
        label: [
            { locale: "de_de", value: "Applikationen" },
            { locale: "en_us", value: "Applications" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        requiredPermission: typesystem_1.ServicePermissions.APPLICATIONS_READ
    },
    {
        label: [
            { locale: "de_de", value: "CMS Seiten" },
            { locale: "en_us", value: "CMS Pages" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        path: typesystem_1.F_CMS,
        icon: "cms",
        requiredPermission: typesystem_1.ServicePermissions.CMS_READ
    },
    {
        icon: "optin",
        path: typesystem_1.F_OPTIN,
        label: [
            { locale: "de_de", value: "Einverständniserklärungen" },
            { locale: "en_us", value: "Opt-Ins" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        requiredPermission: typesystem_1.ServicePermissions.OPT_IN_WRITE
    },
    {
        label: [
            { locale: "de_de", value: "PDF Vorlagen" },
            { locale: "en_us", value: "PDF Templates" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        icon: "pdf",
        path: typesystem_1.F_PDF_TEMPLATES,
        requiredPermission: typesystem_1.ServicePermissions.PDF_TEMPLATE_READ
    },
    {
        label: [
            { locale: "de_de", value: "Projektdateien" },
            { locale: "en_us", value: "Project Files" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        icon: "files",
        path: typesystem_1.F_FILE
    },
    {
        icon: "i18n",
        path: typesystem_1.F_I18N,
        label: [
            { locale: "de_de", value: "Internationalisierung" },
            { locale: "en_us", value: "Internationalization" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        requiredPermission: typesystem_1.ServicePermissions.INTERNATIONALIZATION_READ
    }
];
exports.UserFeatures = [
    {
        label: [
            { locale: "de_de", value: "Kunden" },
            { locale: "en_us", value: "Customers" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        path: typesystem_1.T_USERS,
        icon: backoffice_icons_1.BackofficeIcons.users
    },
    {
        icon: "email",
        path: typesystem_1.F_EMAIL,
        label: [
            { locale: "de_de", value: "E-mail" },
            { locale: "en_us", value: "Email" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        requiredPermission: typesystem_1.ServicePermissions.EMAILS_READ
    },
    {
        icon: "commercial",
        path: typesystem_1.F_MAILING,
        label: [
            { locale: "de_de", value: "Marketing" },
            { locale: "en_us", value: "Marketing" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        requiredPermission: typesystem_1.ServicePermissions.MAILING_LIST_READ
    }
];
exports.PimFeatures = [
    {
        icon: "products",
        path: "pim/products",
        label: [
            { locale: "de_de", value: "Produkte" },
            { locale: "en_us", value: "Products" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        requiredPermission: typesystem_1.ServicePermissions.PRODUCTS_READ
    },
    {
        label: [
            { locale: "de_de", value: "Bestellungen" },
            { locale: "en_us", value: "Orders" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        path: "pim/orders",
        icon: backoffice_icons_1.BackofficeIcons.orders,
        requiredPermission: typesystem_1.ServicePermissions.ORDERS_READ
    },
    {
        label: [
            { locale: "de_de", value: "Preiszone" },
            { locale: "en_us", value: "Price Zone" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        path: "pim/pricezones",
        icon: backoffice_icons_1.BackofficeIcons.pricezone,
        requiredPermission: typesystem_1.ServicePermissions.PRODUCTS_READ
    },
    {
        label: [
            { locale: "de_de", value: "Zulieferer" },
            { locale: "en_us", value: "Supplier" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        path: "pim/supplier",
        icon: backoffice_icons_1.BackofficeIcons.suppliers,
        requiredPermission: typesystem_1.ServicePermissions.PRODUCTS_WRITE
    }
];
exports.CrmFeatures = [exports.ContactsNavigationNode];
exports.WorkflowFeatures = [
    {
        icon: "workflow",
        path: typesystem_1.F_WORKFLOW,
        label: [
            { locale: "de_de", value: "Workflows" },
            { locale: "en_us", value: "Workflows" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        requiredPermission: typesystem_1.ServicePermissions.WORKFLOW_READ
    },
    {
        icon: "export",
        path: "export",
        label: [
            { locale: "en_us", value: "Data Export" },
            { locale: "de_de", value: "Daten Export" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        requiredPermission: typesystem_1.ServicePermissions.EXPORTERS_EXECUTE
    },
    {
        label: [
            { locale: "de_de", value: "Warteschlange" },
            { locale: "en_us", value: "Task Queue" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        path: typesystem_1.F_TASK,
        icon: backoffice_icons_1.BackofficeIcons.taskqueue,
        requiredPermission: typesystem_1.ServicePermissions.TASKS_READ
    }
];
exports.OtherFeatures = [
    {
        icon: "audit",
        path: "audit-log",
        label: [
            { locale: "de_de", value: "Auditprotokoll" },
            { locale: "en_us", value: "Audit Log" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        requiredPermission: typesystem_1.ServicePermissions.AUDIT_READ
    },
    {
        icon: "key",
        path: "service-token",
        label: [{ value: "Servicetokens" }],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        requiredPermission: typesystem_1.ServicePermissions.TENANT_ADMIN
    },
    {
        icon: "custom",
        path: typesystem_1.F_CUSTOM + "-data",
        label: [
            { locale: "en_us", value: "Extensions" },
            { locale: "de_de", value: "Erweiterungen" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        requiredPermission: typesystem_1.ServicePermissions.TENANT_ADMIN
    },
    {
        icon: "configuration",
        path: typesystem_1.F_CONFIGURATION,
        label: [
            { locale: "en_us", value: "Configurations" },
            { locale: "de_de", value: "Konfigurationen" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item,
        requiredPermission: typesystem_1.ServicePermissions.CONFIGURATION_WRITE
    },
    {
        icon: "devices",
        path: "devices",
        label: [
            { locale: "en_us", value: "External Devices" },
            { locale: "de_de", value: "Externe Geräte" }
        ],
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Item
    }
];
exports.ProjectNavigationFeatures = [
    ...exports.CheckinFeatures,
    ...exports.ContentFeatures,
    ...exports.UserFeatures,
    ...exports.PimFeatures,
    ...exports.CrmFeatures,
    ...exports.WorkflowFeatures,
    ...exports.OtherFeatures
];
exports.DefaultProjectNavigation = [
    { type: axios_api_client_1.NavigationEntryDtoTypeEnum.Divider, label: [{ value: "Check-In App" }] },
    ...exports.CheckinFeatures,
    {
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Divider,
        label: [
            { locale: "de_de", value: "Inhalt" },
            { locale: "en_us", value: "Content" }
        ]
    },
    ...exports.ContentFeatures,
    ...exports.CrmFeatures,
    {
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Divider,
        label: [
            { locale: "de_de", value: "E-Commerce" },
            { locale: "en_us", value: "E-Commerce" }
        ]
    },
    ...exports.PimFeatures,
    ...exports.UserFeatures,
    {
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Divider,
        label: [
            { locale: "de_de", value: "Aufgaben" },
            { locale: "en_us", value: "Tasks" }
        ]
    },
    ...exports.WorkflowFeatures,
    {
        type: axios_api_client_1.NavigationEntryDtoTypeEnum.Divider,
        label: [
            { locale: "de_de", value: "Weitere Module" },
            { locale: "en_us", value: "Other Modules" }
        ]
    },
    ...exports.OtherFeatures
];
//# sourceMappingURL=project-navigation.features.js.map